Function to generate a scatter plot of the simulated data focusing on ribosomal proportion.
plot_ribosomal_penalty(
qc_summary,
palette = c("grey", "#7023FD", "#E60006"),
target_damage = c(0.5, 1)
)A ggplot2 plot
A data frame containing the quality control summary for cells.
A character vector specifying the color gradient used for coloring the damage levels.
Numeric vector specifying the target damage levels for color scaling.
This function visualizes the distribution of mitochondrial and ribosomal proportion for cells with altered counts.